@@ -5,14 +5,14 @@ import os
 import re
 import sqlite3
 from sqlite3 import ProgrammingError
-from typing import Dict, List, Optional, Type, Union
+from typing import Dict, List, Type, Union
 
 from pypika import Query, Table, functions
 from yoyo import get_backend, read_migrations
 
 from ...exceptions import EntityNotFoundError
-from ...model import EntityID
-from .abstract import Entity, Repository
+from ...model import EntityID, EntityT
+from .abstract import Repository
 
 log = logging.getLogger(__name__)
 
@@ -37,15 +37,13 @@ class PypikaRepository(Repository):
     def __init__(
         self,
         database_url: str = "",
-        search_exception: Optional[bool] = None,
     ) -> None:
         """Initialize the repository attributes.
 
         Args:
             database_url: URL specifying the connection to the database.
-            models: List of stored entity models.
         """
-        super().__init__(database_url, search_exception)
+        super().__init__(database_url)
         database_file = database_url.replace("sqlite:///", "")
         if not os.path.isfile(database_file):
             try:
@@ -68,16 +66,16 @@ class PypikaRepository(Repository):
         return self.cursor.execute(str(query))
 
     @staticmethod
-    def _table(entity: Entity) -> Table:
+    def _table(entity: EntityT) -> Table:
         """Return the table of the selected entity object."""
         return Table(entity.model_name.lower())
 
     @staticmethod
-    def _table_model(model: Type[Entity]) -> Table:
+    def _table_model(model: Type[EntityT]) -> Table:
         """Return the table of the selected entity class."""
         return Table(model.__name__.lower())
 
-    def _add(self, entity: Entity) -> Entity:
+    def _add(self, entity: EntityT) -> EntityT:
         """Append an entity to the repository.
 
         If the id is not set, autoincrement the last.
@@ -110,7 +108,7 @@ class PypikaRepository(Repository):
 
         return entity
 
-    def delete(self, entity: Entity) -> None:
+    def delete(self, entity: EntityT) -> None:
         """Delete an entity from the repository.
 
         Args:
@@ -132,9 +130,9 @@ class PypikaRepository(Repository):
     def _get(
         self,
         value: EntityID,
-        model: Type[Entity],
+        model: Type[EntityT],
         attribute: str = "id_",
-    ) -> List[Entity]:
+    ) -> List[EntityT]:
         """Obtain all entities from the repository that match an id_.
 
         If the attribute argument is passed, check that attribute instead.
@@ -156,23 +154,23 @@ class PypikaRepository(Repository):
 
         return self._build_entities(model, query)
 
-    def _all(self, model: Type[Entity]) -> List[Entity]:
-        """Get all the entities from the repository whose class is included in models.
+    def _all(self, model: Type[EntityT]) -> List[EntityT]:
+        """Get all the entities from the repository that match a model.
 
         Particular implementation of the database adapter.
 
         Args:
-            models: Entity class to obtain.
+            model: Entity class to obtain.
         """
         table = self._table_model(model)
         query = Query.from_(table).select("*")
         return self._build_entities(model, query)
 
-    def _build_entities(self, model: Type[Entity], query: Query) -> List[Entity]:
+    def _build_entities(self, model: Type[EntityT], query: Query) -> List[EntityT]:
         """Build Entity objects from the data extracted from the database.
 
         Args:
-            models: The model of the entity to build
+            model: Entity class model to build.
             query: pypika query of the entities you want to build
         """
         cursor = self._execute(query)
@@ -180,7 +178,7 @@ class PypikaRepository(Repository):
         entities_data = cursor.fetchall()
         attributes = [description[0] for description in cursor.description]
 
-        entities: List[Entity] = []
+        entities = []
         for entity_data in entities_data:
             entity_dict = {
                 attributes[index]: entity_data[index]
@@ -198,8 +196,8 @@ class PypikaRepository(Repository):
     def _search(
         self,
         fields: Dict[str, EntityID],
-        model: Type[Entity],
-    ) -> List[Entity]:
+        model: Type[EntityT],
+    ) -> List[EntityT]:
         """Get the entities whose attributes match one or several conditions.
 
         Particular implementation of the database adapter.
