@@ -2,7 +2,7 @@
 
 import os
 from datetime import datetime
-from typing import Any, AnyStr, Dict, Generic, List, Optional, Union
+from typing import Any, AnyStr, Dict, Generic, List, Optional, Sequence, TypeVar, Union
 
 from pydantic import AnyHttpUrl, BaseModel, PrivateAttr
 
@@ -109,6 +109,10 @@ class Entity(BaseModel):
         self._defined_values = {}
 
 
+EntityT = TypeVar("EntityT", bound=Entity)
+EntityOrEntitiesT = TypeVar("EntityOrEntitiesT", Sequence[Entity], Entity)
+
+
 class File(Entity, Generic[AnyStr]):
     """Model a computer file."""
 
