@@ -6,11 +6,11 @@ add them to the cases.
 
 import logging
 import os
+from pathlib import Path
 from typing import Any, List
 
 import pytest
 from _pytest.logging import LogCaptureFixture
-from py._path.local import LocalPath
 from pydantic import ValidationError
 from tests.cases.entities import AuthorFactory, BookFactory, GenreFactory
 from tests.cases.model import Book
@@ -21,6 +21,7 @@ from repository_orm import (
     Repository,
     TinyDBRepository,
 )
+from repository_orm.adapters.data.tinydb import _regexp_in_list
 from repository_orm.exceptions import TooManyEntitiesError
 
 from ..cases import Entity, RepositoryTester
@@ -50,7 +51,7 @@ class TestDBConnection:
         repo_tester.assert_schema_exists(database, caplog)
 
     def test_repository_handles_inexistent_database_file(
-        self, repo: Repository, tmpdir: LocalPath
+        self, repo: Repository, tmp_path: Path
     ) -> None:
         """
         Given: A database url pointing to an inexistent file
@@ -59,7 +60,7 @@ class TestDBConnection:
             The FakeRepository should not create any file, as all entities are stored in
             memory.
         """
-        database_url = str(tmpdir.join("inexistent.db"))  # type: ignore
+        database_url = str(tmp_path / "inexistent.db")
 
         result = repo.__class__(database_url=database_url)
 
@@ -683,6 +684,20 @@ class TestSearch:
 
         assert result == [author]
 
+    # W0613: the fixture is used to create the data
+    def test_repository_search_returns_empty_list_if_type_doesnt_match(
+        self,
+        repo: Repository,
+        inserted_entities: List[Entity],  # noqa: W0613
+    ) -> None:
+        """
+        If an object has a property that is an integer and we try to search for a string
+        it won't raise an error but return an empty list.
+        """
+        result = repo.search({"id": "wrong_type"}, Book)
+
+        assert result == []
+
 
 class TestSearchOnLists:
     """
@@ -786,7 +801,7 @@ class TestDelete:
         self,
         database: Any,
         repo: Repository,
-        repo_tester: RepositoryTester[Entity],
+        repo_tester: RepositoryTester[Repository],
         inserted_entities: List[Entity],
     ) -> None:
         """
@@ -998,3 +1013,17 @@ def test_tinydb_raises_error_if_wrong_model_data(
         "Error loading the model Entity for the register "
         "{'id_': 1, 'model_type_': 'entity'}",
     ) in caplog.record_tuples
+
+
+def test_regexp_in_list_handles_none_as_argument() -> None:
+    """
+    Given: Nothing
+    When: _regexp_in_list is called with None
+    Then: It returns false
+
+    Sometimes Query.test(func, ...) passes a None element to the func, we need to catch
+    this case
+    """
+    result = _regexp_in_list(None, "test")
+
+    assert not result
